@@ -12,7 +12,6 @@
 #include "core/exceptions/FileNotFoundException.hpp"
 #include "core/exceptions/ExternalLibException.hpp"
 #include "community/CommunityStructure.hpp"
-#include "community/label_propagation.hpp"
 #include "community/PillarCommunity.hpp"
 #include "community/_impl/abacus_utils.hpp"
 
@@ -31,13 +30,13 @@ namespace net {
  * @param min_layers minimum number of layers in a community
  * @return a set of actor communities
  */
-template <typename M, typename L>
-std::unique_ptr<CommunityStructure<PillarCommunity<L>>>
-abacus(
-    const M* mnet,
-    int min_actors,
-    int min_layers
-);
+template <typename M>
+std::unique_ptr<CommunityStructure<M>>
+                                    abacus(
+                                        const M* mnet,
+                                        int min_actors,
+                                        int min_layers
+                                    );
 
 }
 }
