@@ -4,7 +4,6 @@
 
 #include "core/utils/pretty_printing.hpp"
 #include "community/CommunityStructure.hpp"
-#include "community/VertexLayerCommunity.hpp"
 #include "community/_impl/cutils.hpp"
 #include "Eigen/Sparse"
 #include "Eigen/Dense"
@@ -15,13 +14,13 @@ namespace uu {
 namespace net {
 
 template <typename M, typename G>
-std::unique_ptr<CommunityStructure<VertexLayerCommunity<const G>>>
-generalized_louvain(
-    const M* mnet,
-    double gamma,
-    double omega,
-    size_t limit
-);
+std::unique_ptr<CommunityStructure<M>>
+                                    generalized_louvain(
+                                        const M* mnet,
+                                        double gamma,
+                                        double omega,
+                                        size_t limit
+                                    );
 
 
 }
