@@ -4,6 +4,7 @@
 
 #include "community/CommunityStructure.hpp"
 #include "community/Community.hpp"
+#include "networks/Network.hpp"
 #include "objects/Vertex.hpp"
 #include <memory>
 
@@ -11,10 +12,11 @@
 namespace uu {
 namespace net {
 
-template <typename G> std::unique_ptr<CommunityStructure<Community<const Vertex*>>>
-louvain(
-    const G* g
-);
+template <typename G>
+std::unique_ptr<CommunityStructure<Network>>
+        louvain(
+            const G* g
+        );
 
 }
 }
